@@ -146,12 +146,19 @@ class SQLiteServer(SQLiteZMQProcess):
             if not (sys.version_info.major == 3 and sys.version_info.minor >= 7):
                 LOG.warning("Backup requires Python 3.7 or higher")
                 raise SQLiteRxBackUpError("SQLite backup requires Python 3.7 or higher")
+
+            if sys.platform.startswith('win'):
+                LOG.warning("Backup is not supported on Windows")
+                raise SQLiteRxBackUpError("SQLite backup is not supported on Windows")
+
+            if platform.python_implementation().lower() == 'pypy':
+                LOG.warning("Backup is not supported on PyPy python implementation")
+                raise SQLiteRxBackUpError("SQLite backup is not supported on MacOS for PyPy python implementation")
             
             sqlite_backup = SQLiteBackUp(src=database, target=backup_database)
             self.back_up_recurring_thread = RecurringTimer(function=sqlite_backup, interval=backup_interval)
             self.back_up_recurring_thread.daemon = True
 
-
     def setup(self):
         """
         Start a zmq.REP socket stream and register a callback :class: `sqlite_rx.server.QueryStreamHandler`
@@ -169,10 +176,8 @@ class SQLiteServer(SQLiteZMQProcess):
         self.rep_stream.on_recv(QueryStreamHandler(self.rep_stream,
                                                    self._database,
                                                    self._auth_config))
-    
 
     def handle_signal(self, signum, frame):
-
         LOG.info("SQLiteServer %s PID %s received %r", self, self.pid, signum)
         LOG.info("SQLiteServer Shutting down")
 
@@ -182,10 +187,8 @@ class SQLiteServer(SQLiteZMQProcess):
         
         if self.back_up_recurring_thread:
             self.back_up_recurring_thread.cancel()
-        
         os._exit(os.EX_OK)
 
-        
     def run(self):
         LOG.info("Setting up signal handlers")
 
